/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */

package de.bsvrz.ste.rdstmc.verkehrsanalyse;

import de.bsvrz.ste.rdstmc.konfiguration.StrassenAbschnitt;
import de.bsvrz.ste.rdstmc.konfiguration.StrassenTeilSegment;

/**
 * Modelliert einen lokalen Störfall in Bezug auf einen Messquerschnitt
 *
 * @author Dambach Werke GmbH
 * @author Stefan Sans
 * @version $Revision: 1.1 $ / $Date: 2008/10/31 13:49:25 $ / ($Author: Sans $)
 */
public class StreckenbezogenerStoerfall extends Stoerfall
{

  /**
   * Instanziiert einen streckenbezogenen Störfall für einen Strassenabschnitt auf einem Strassensegment
   *
   * @param sa der Strassenabschnitt, für den der lokale Störfall instanziiert werden soll
   * signifikantesSegment das Strassensegment, welches für diesen Störfall signifikant ist,
   * falls Start-und End-MQ auf verschiedene Strassensegmente verweisen
   * @param stoerfallSituation StoerfallSituation
   */
  public StreckenbezogenerStoerfall(StrassenAbschnitt sa, StoerfallSituation stoerfallSituation)
  {
    super(sa, stoerfallSituation);

//    _startOffset = getSegment().getMessQuerschnitte().contains(getObjekt().getVonMq()) ?
//        getObjekt().getVonMq().getOffset() : getSegment().getLaenge();
//    _endOffset = getSegment().getMessQuerschnitte().contains(getObjekt().getNachMq()) ?
//          getObjekt().getNachMq().getOffset() : getSegment().getLaenge();

    _startOffset = getSegment().getMessQuerschnitte().contains(sa.getVonMq()) ?
        sa.getVonMq().getOffset() : 0; //getSegment().getLaenge();
    _endOffset = getSegment().getMessQuerschnitte().contains(sa.getNachMq()) ?
          sa.getNachMq().getOffset() : getSegment().getLaenge();
  }

  public StreckenbezogenerStoerfall(StrassenTeilSegment sts, StoerfallSituation stoerfallSituation)
  {
    super(sts, stoerfallSituation);

//    _startOffset = getSegment().getMessQuerschnitte().contains(getObjekt().getVonMq()) ?
//        getObjekt().getVonMq().getOffset() : getSegment().getLaenge();
//    _endOffset = getSegment().getMessQuerschnitte().contains(getObjekt().getNachMq()) ?
//          getObjekt().getNachMq().getOffset() : getSegment().getLaenge();

    _startOffset = sts.getOffset();
    _endOffset = _startOffset + sts.getLaenge();
  }

  /**
   * Startoffset in m auf dem Straßensegment dieses Stöfalls
   */
  private long _startOffset;

  /**
   * Endoffset in m auf dem Straßensegment dieses Stöfalls
   */
  private long _endOffset;

//  @Override
//  protected StrassenAbschnitt getObjekt()
//  {
//    return (StrassenAbschnitt)super.getObjekt();
//  }

  /**
   * @return den Startoffset in m auf dem Straßensegment dieses Stöfalls
   */
  long getStartOffset()
  {
    long result = _startOffset;
    result = result < 0 ? 0 : result;
    result =  result > getSegment().getLaenge() ? getSegment().getLaenge() : result;
    return result;
  }

  /**
   * @return den Endoffset in m auf dem Straßensegment dieses Stöfalls
   */
  long getEndOffset()
  {
   long result = _endOffset;
   result = result < 0 ? 0 : result;
   result =  result > getSegment().getLaenge() ? getSegment().getLaenge() : result;
   return result;
  }
  
}
